import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.component_arithmetic.qt.equation_editor is deprecated, use glue_qt.dialogs.component_arithmetic.equation_editor) instead', GlueDeprecationWarning)
from glue_qt.dialogs.component_arithmetic.equation_editor import *  # noqa
