import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.edit_subset_mode_toolbar is deprecated, use glue_qt.app.edit_subset_mode_toolbar) instead', GlueDeprecationWarning)
from glue_qt.app.edit_subset_mode_toolbar import *  # noqa
