import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.plugins.dendro_viewer.qt.options_widget is deprecated, use glue_qt.plugins.dendro_viewer.options_widget) instead', GlueDeprecationWarning)
from glue_qt.plugins.dendro_viewer.options_widget import *  # noqa
