import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.autolinker.qt.autolinker is deprecated, use glue_qt.dialogs.autolinker.autolinker) instead', GlueDeprecationWarning)
from glue_qt.dialogs.autolinker.autolinker import *  # noqa
