import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.data_exporters.qt.dialog is deprecated, use glue_qt.core.data_exporters.dialog) instead', GlueDeprecationWarning)
from glue_qt.core.data_exporters.dialog import *  # noqa
