import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.layer_style_editor_subset is deprecated, use glue_qt.viewers.image.layer_style_editor_subset) instead', GlueDeprecationWarning)
from glue_qt.viewers.image.layer_style_editor_subset import *  # noqa
