import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.plugins.tools.pv_slicer.qt.pv_slicer is deprecated, use glue_qt.plugins.tools.pv_slicer.pv_slicer) instead', GlueDeprecationWarning)
from glue_qt.plugins.tools.pv_slicer.pv_slicer import *  # noqa
