import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.icons.qt.helpers is deprecated, use glue_qt.icons.helpers) instead', GlueDeprecationWarning)
from glue_qt.icons.helpers import *  # noqa
