import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.link_editor.qt.data_graph is deprecated, use glue_qt.dialogs.link_editor.data_graph) instead', GlueDeprecationWarning)
from glue_qt.dialogs.link_editor.data_graph import *  # noqa
