import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.common.qt.component_tree_widget is deprecated, use glue_qt.dialogs.common.component_tree_widget) instead', GlueDeprecationWarning)
from glue_qt.dialogs.common.component_tree_widget import *  # noqa
